# Pacote para ter acesso a funcoes de tratamento e extracao de dados RDS
* Aqui se localiza biblioteca etl
* Que faz o processamento da etl lambda, joguei ela para um pacote para facilidade de importacao
* Como instalar?
1- Para baixar pip install etl
2- Pronto
